@@ -7,17 +7,13 @@
 from __future__ import annotations
 
 import importlib
+import importlib.metadata
 import inspect
 import os
 import sys
 import warnings
 from pathlib import Path
 
-if sys.version_info < (3, 8):
-    import importlib_metadata
-else:
-    import importlib.metadata as importlib_metadata
-
 try:
     import scikit_build_core
 except ModuleNotFoundError:
@@ -32,7 +28,7 @@ try:
     from scikit_build_core import __version__ as version
 except ModuleNotFoundError:
     try:
-        version = importlib_metadata.version("scikit_build_core")
+        version = importlib.metadata.version("scikit_build_core")
     except ModuleNotFoundError:
         msg = (
             "Package should be installed to produce documentation! "
@@ -60,17 +56,19 @@ author = "Henry Schreiner"
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
+    "conftabs",
     "myst_parser",
+    "sphinx-jsonschema",
     "sphinx.ext.autodoc",
     "sphinx.ext.intersphinx",
     "sphinx.ext.linkcode",
     "sphinx.ext.mathjax",
     "sphinx.ext.napoleon",
+    "sphinx_autodoc_typehints",
     "sphinx_copybutton",
     "sphinx_inline_tabs",
-    "sphinx_autodoc_typehints",
-    "conftabs",
-    "sphinx-jsonschema",
+    "sphinx_tippy",
+    "sphinxcontrib.programoutput",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -87,17 +85,24 @@ exclude_patterns = [
     "Thumbs.db",
     ".DS_Store",
     ".env",
-    ".venv",
+    "**.venv",
     "examples/downstream",
 ]
 
 
 intersphinx_mapping = {
+    "cmake": ("https://cmake.org/cmake/help/latest/", None),
     "python": ("https://docs.python.org/3", None),
     "packaging": ("https://packaging.pypa.io/en/stable", None),
     "setuptools": ("https://setuptools.pypa.io/en/latest", None),
     "hatchling": ("https://hatch.pypa.io/latest", None),
 }
+tippy_rtd_urls = [
+    val[0]
+    for key, val in intersphinx_mapping.items()
+    # Only works with RTD hosted intersphinx
+    if key not in ("hatchling", "python", "cmake")
+]
 
 nitpick_ignore = [
     ("py:class", "setuptools.dist.Distribution"),
@@ -111,6 +116,9 @@ linkcheck_anchors_ignore = [
     "default-versioning-scheme",
     "git-archives",
 ]
+linkcheck_ignore = [
+    r"https://github.com/search\?.*",
+]
 # -- Options for HTML output -------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
